@@ -3,7 +3,7 @@
  * Copyright (C) 2002 Jorn Baayen
  * Copyright (C) 2003, 2004 Christian Persch
  * Copyright (C) 2005 Juerg Billeter
- * Copyright (C) 2005 Don Scorgie <DonScorgie@Blueyonder.co.uk>
+ * Copyright (C) 2005 Don Scorgie <Don@Scorgie.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -94,7 +94,7 @@ print_present_config_dialog (YelpPrintInfo *info)
     int ret;
 
     if (!info->print_dialog) {
-	info->print_dialog = gtk_print_unix_dialog_new ("Print Dialog", 
+	info->print_dialog = gtk_print_unix_dialog_new (_("Print"), 
 							GTK_WINDOW (info->owner));
 	gtk_print_unix_dialog_set_settings (
 				  GTK_PRINT_UNIX_DIALOG (info->print_dialog), 
@@ -254,7 +254,7 @@ yelp_print_verify_postscript (GtkPrinter *printer, GtkWidget *print_dialog)
 {
     if (!gtk_printer_accepts_ps (printer)) {
 	GtkDialog *dialog;
-	dialog = gtk_message_dialog_new ( GTK_WINDOW (print_dialog),
+	dialog = (GtkDialog *) gtk_message_dialog_new ( GTK_WINDOW (print_dialog),
 					  GTK_DIALOG_MODAL,
 					  GTK_MESSAGE_ERROR,
 					  GTK_BUTTONS_OK,
@@ -357,12 +357,11 @@ yelp_print_present_status_dialog (YelpWindow *window, YelpPrintInfo *info)
     if (info->dialog != NULL)
 	return;
     
-    info->dialog = gtk_message_dialog_new_with_markup (GTK_WINDOW (window), 
-						       GTK_DIALOG_DESTROY_WITH_PARENT,
-						       GTK_MESSAGE_INFO,
-						       GTK_BUTTONS_CANCEL,
-						       "<b>%s</b>",
-						       _("Printing"));
+    info->dialog = gtk_message_dialog_new (GTK_WINDOW (window), 
+					   GTK_DIALOG_DESTROY_WITH_PARENT,
+					   GTK_MESSAGE_INFO,
+					   GTK_BUTTONS_CANCEL,
+					   "%s", _("Printing"));
     gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (info->dialog),
 					      _("Waiting to print"));
     info->progress = gtk_progress_bar_new ();
